#!/bin/ksh
# (c) Copyright IBM Corp. 2005, 2006 All rights reserved.
# This script is owned by International Business Machines Corporation or
# one of its subsidiaries ("IBM") and is copyrighted and licensed, not sold.
# You may copy, modify, and distribute this script in any form without
# payment to IBM, for any purpose including developing, using, marketing or
# distributing programs that include or are derivative works of the script.
# The script provided to you on an "AS IS" basis, without warranty of
# any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER
# EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE. IBM shall not be liable for indemnification or any damages you suffer 
# as a result of using, modifying or distributing the script or its derivatives.
# Each copy of any portion of this script or any derivative work, must
# include the above copyright notice and disclaimer of warranty.
# 

function NOSESSION {
    echo 
    echo "This script should be run as the correct db2 user"
    if [ "$ForceSession" = "Yes" ] ; then
	echo "I already tried to switch once and it did not work, giving up"
	ERROREXIT
    else
	echo "Trying to switch for you..."
	su - $DB2UserID -c "$PWD/createUDDI30.sh $DB2UserID $DB2Password $DataBaseName $SQLPATH x"
	if [ $? -eq 1 ] ; then WRONGUSER ; fi
	if [ $? -gt 0 ] ; then ERROREXIT ; fi
	exit 0
    fi
}

function WRONGUSER {
    echo .
    echo "you need to use a valid DB2 userid password combination"
    ERROREXIT
}

function WRONGPATH {
    echo 
    echo "A required file $SQLPATH/uddi30crt_10_prereq_db2.sql is missing"
    echo 
    echo Make sure you have correctly specified the path to the SQL files
    ERROREXIT
}

function ERROREXIT {
    db2 connect reset
    echo .
    echo ERROR DETECTED
    echo .
    echo "USAGE: createUDDI30.sh <db2userid> <db2password> <dbName> <path_to_SQL_files>"
    echo .
    exit 2
}

# =========================== Start of script ==============================
echo "========================================================="
echo 
echo "This script creates the UDDI DB2 database"
echo 
echo "The script assumes you have:"
echo "DB2 v8 installed and running"
echo 
echo "========================================================="
echo 

DB2UserID=db2user
DB2Password=db2pass

if [ -z "$1" ] ; then ERROREXIT ; else DB2UserID=$1 ; fi
if [ -z "$2" ] ; then ERROREXIT ; else DB2Password=$2 ; fi
if [ -z "$3" ] ; then ERROREXIT ; else DataBaseName=$3 ; fi
if [ -z "$4" ] ; then ERROREXIT ; else SQLPATH=$4 ; fi
if [ "$5" = "x" ] ; then ForceSession=Yes ; else ForceSession=No ; fi
if [ ! -z "$6" ] ; then ERROREXIT ; fi

BufferPoolName=$DataBaseName"TS"

echo  "DB2UserID: $DB2UserID"
echo  "DB2Password: $DB2Password"
echo  "DataBaseName: $DataBaseName"
echo  "BufferPoolName: $BufferPoolName"
echo  "SQLPath: $SQLPATH"
echo 

if [ ! -e "$SQLPATH/uddi30crt_10_prereq_db2.sql" ] ; then WRONGPATH ; fi

# just to check that we have a db2cmd session
db2 list active databases
if [ $? -gt 3 ] ; then NOSESSION ; fi

db2set DB2CODEPAGE=1208
if [ $? -gt 0 ] ; then ERROREXIT ; fi

rc=4
while [ $rc -eq 4 ] ; do
    echo "Waiting for all databases to disconnect"
    db2 list active databases
    db2 force application all
    if [ $? -gt 0 ] ; then ERROREXIT ; fi
    sleep 10

    db2 db2stop
    rc=$?
    if [ $rc -eq 4 ] ; then continue ; fi
    if [ $rc -gt 0 ] ; then ERROREXIT ; fi
done

db2 db2start
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 drop database $DataBaseName
if [ $? -gt 4 ] ; then ERROREXIT ; fi
# database may not exist so rc = 4

db2 create database $DataBaseName using codeset UTF-8 territory en
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 connect to $DataBaseName user $DB2UserID using $DB2Password
if [ $? -gt 3 ] ; then WRONGUSER ; fi
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 update db cfg for $DataBaseName using applheapsz 2048
if [ $? -gt 2 ] ; then ERROREXIT ; fi

db2 update db cfg for $DataBaseName using logfilsiz 8192
if [ $? -gt 3 ] ; then ERROREXIT ; fi

db2 create bufferpool $BufferPoolName size 250 pagesize 32K
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 commit
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 flush package cache dynamic
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 connect to $DataBaseName user $DB2UserID using $DB2Password
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 create regular tablespace uddits pagesize 32K managed by system using \(\'$DataBaseName\'\) extentsize 64 prefetchsize 32 bufferpool $BufferPoolName
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 create system temporary tablespace TempTableSpacename pagesize 32K managed by system using \(\'TempTableSpacename\'\) extentsize 32 overhead 14.06 prefetchsize 32 transferrate 0.33 bufferpool $BufferPoolName
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 terminate
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2set DB2CODEPAGE=1208
if [ $? -gt 0 ] ; then ERROREXIT ; fi

# NOTE these SQL calls need to be done in this order - they have interdependencies
db2 connect to $DataBaseName user $DB2UserID using $DB2Password
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_10_prereq_db2.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_20_tables_generic.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_25_tables_db2udb.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_30_constraints_generic.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_35_constraints_db2udb.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_40_views_generic.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_45_views_db2udb.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -vf "$SQLPATH/uddi30crt_50_triggers_db2udb.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_60_insert_initial_static_data.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 -tvf "$SQLPATH/uddi30crt_70_insert_default_database_indicator.sql"
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 connect reset
if [ $? -gt 0 ] ; then ERROREXIT ; fi

db2 terminate
if [ $? -gt 0 ] ; then ERROREXIT ; fi

echo "================== UDDI DATABASE CREATED SUCCESSFULLY ===================="
exit 0

# ==================== END OF SCRIPT ==============================================

