#!/bin/ksh
# (c) Copyright IBM Corp. 2005, 2006 All rights reserved.
# This script is owned by International Business Machines Corporation or
# one of its subsidiaries ("IBM") and is copyrighted and licensed, not sold.
# You may copy, modify, and distribute this script in any form without
# payment to IBM, for any purpose including developing, using, marketing or
# distributing programs that include or are derivative works of the script.
# The script provided to you on an "AS IS" basis, without warranty of
# any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER
# EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE. IBM shall not be liable for indemnification or any damages you suffer 
# as a result of using, modifying or distributing the script or its derivatives.
# Each copy of any portion of this script or any derivative work, must
# include the above copyright notice and disclaimer of warranty.
# 

function NOWASADMIN {
    echo 
    echo "The required file $USER_INSTALL_ROOT/bin/wsadmin.sh was not found"
    echo "This is supplied with WebSphere in a default location"
    echo "Make sure you run . setupCmdLine.sh before this script"
    ERROREXIT
}

function NOJACL {
    echo 
    echo "The required file $JACLNAME was not found"
    echo "This should be supplied with this script" 
    echo "and located in the current directory ($PWD)"
    echo "Locate a copy of $JACLNAME and try again"
    ERROREXIT
}

function ERROREXIT {
    echo 
    echo ERROR DETECTED
    echo 
    echo "USAGE: . setupCmdLine.sh"
    echo "       for base setup: setupUDDI.sh <db2userid> <db2password> <db2hostname> <dbName> <WASuserid> <WASpassword> baseserver <serverName>"
    echo "       for ND setup: setupUDDI.sh <db2userid> <db2password> <db2hostname> <dbName> <WASuserid> <WASpassword> NDserver <serverName>"
    echo "       for cluster setup: setupUDDI.sh <db2userid> <db2password> <db2hostname> <dbName> <WASuserid> <WASpassword> cluster <clusterName>"
    echo .
    exit 2
}


# ============================= Start of script ==============================
echo "========================================================="
echo 
echo "This script installs and initializes UDDI"
echo 
echo "The script assumes you have:"
echo 
echo "WebSphere 61 installed and running"
echo 
echo "Run setupCmdLine.sh from the appropriate WAS profile"
echo 
echo "========================================================="
echo 

DB2UserID=db2user
DB2Password=db2pass
DB2Host=machineX
WASUserID=WASuser
WASPassword=WASpass
serverName=server1
cluster=BASE

if [ -z "$1" ] ; then ERROREXIT ; else DB2UserID=$1 ; fi
if [ -z "$2" ] ; then ERROREXIT ; else DB2Password=$2 ; fi
if [ -z "$3" ] ; then ERROREXIT ; else DB2Host=$3 ; fi
if [ -z "$4" ] ; then ERROREXIT ; else DB2Port=$4 ; fi
if [ -z "$5" ] ; then ERROREXIT ; else DataBaseName=$5 ; fi
if [ -z "$6" ] ; then ERROREXIT ; else WASUserID=$6 ; fi
if [ -z "$7" ] ; then ERROREXIT ; else WASPassword=$7 ; fi
if [ "$8" = "cluster" ] ; then
    cluster=YES
elif [ "$8" = "NDserver" ] ; then
    cluster=NO
elif [ "$8" = "baseserver" ] ; then
    cluster=BASE
else
    echo "Invalid install type $8 found, expected cluster, NDserver or baseserver"
    ERROREXIT
fi
if [ -z "$9" ] ; then ERROREXIT ; else serverName=$9 ; fi
#if [ ! -z "$10" ] ; then ERROREXIT ; fi


if [ -z "$USER_INSTALL_ROOT" ] ; then
    if [ -z "$CONFIG_ROOT" ] ; then
	NOWSADMIN
    else
	echo "USER_INSTALL_ROOT not set - guessing from CONFIG_ROOT"
	export USER_INSTALL_ROOT=`echo $CONFIG_ROOT | sed 's/\/config$//'`
    fi
fi

echo  DB2UserID: $DB2UserID
echo  DB2Password: $DB2Password
echo  DB2Host: $DB2Host
echo  DB2Port: $DB2Port
echo  DataBaseName: $DataBaseName
echo  was_home: $WAS_HOME
echo  user_install_root: $USER_INSTALL_ROOT
echo  cluser mode: $cluster
echo  server/cluster name: $serverName
echo .

JACLNAME=tuddiDeploy.jacl

if [ ! -e "$JACLNAME" ] ; then NOJACL ; fi
if [ ! -e "$USER_INSTALL_ROOT/bin/wsadmin.sh" ] ; then NOWASADMIN ; fi

export PATH=$USER_INSTALL_ROOT/bin:$JAVA_HOME/bin:$PATH

echo "deploying the UDDI into WAS and creating JDBC connections"
if [ "$cluster" = "YES" ] ; then
    wsadmin.sh -username $WASUserID -password $WASPassword -f $JACLNAME $DB2UserID $DB2Password $DB2Host $DB2Port $DataBaseName $serverName
    rc=$?
else
    wsadmin.sh -username $WASUserID -password $WASPassword -f $JACLNAME $DB2UserID $DB2Password $DB2Host $DB2Port $DataBaseName $WAS_NODE $serverName
    rc=$?
fi
if [ $rc -gt 0 ] ; then ERROREXIT ; fi

sleep 10

# If its a base AppServer we must restart - otherwise the jacl will have done it
if [ "$cluster" = "BASE" ] ; then
    echo Restarting application server to apply the changes
    echo Stopping the server
    stopServer.sh $serverName -user $WASUserID -password $WASPassword
    if [ $? -lt 0 ] ; then ERROREXIT ; fi
    echo Restarting the server
    startServer.sh $serverName -user $WASUserID -password $WASPassword
    if [ $? -lt -1 ] ; then ERROREXIT ; fi
fi

sleep 5

echo Calling JMX code to configure UDDI properties and policies
java -Djava.ext.dirs="$WAS_EXT_DIRS":"$JAVA_HOME"/jre/lib/ext:"$WAS_HOME"/runtimes:"$WAS_HOME"/plugins:"$WAS_HOME"/plugins/com.ibm.ws.security.crypto_6.1.0:"$JAVA_HOME"/jre/lib/ext:"$WAS_HOME/UDDIReg/clients" -Dwas.profile="$USER_INSTALL_ROOT" -classpath "$WAS_CLASSPATH":. "$CLIENTSOAP" "$CLIENTSAS" "$CLIENTSSL" SetupUDDINodeForEvaluatedConfig $WASUserID $WASPassword
if [ $? -gt 0 ] ; then ERROREXIT ; fi

echo "================== UDDI INSTALLED AND UP SUCCESSFULLY ===================="
exit 0

