 /*
  * (c) Copyright IBM Corp. 2005, 2006 All rights reserved.
  * This [ ]scripts are owned by International Business Machines Corporation or
  * one of its subsidiaries ("IBM") and is copyrighted and licensed, not sold.
  * You may copy, modify, and distribute this script in any form without
  * payment to IBM, for any purpose including developing, using, marketing or
  * distributing programs that include or are derivative works of the script.
  * The script provided to you on an "AS IS" basis, without warranty of
  * any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER
  * EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
  * PURPOSE. IBM shall not be liable for indemnification or any damages you suffer 
  * as a result of using, modifying or distributing the script or its derivatives.
  * Each copy of any portion of this script or any derivative work, must
  * include the above copyright notice and disclaimer of warranty.
  */

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.util.StringTokenizer;

public class EAL4Verify {

    private static boolean SSLFIPSEnabled = false;
    private static boolean SSLEnabled = false;
    private static boolean inVHost = false;
    private static boolean vhSSLFIPSEnabled = false;
    private static boolean vhSSLEnabled = false;

    public EAL4Verify(String serverRoot) {
        System.out.println("EAL4Verify: Verify that IHS is complies with evaluated configuration");
    }

    static String getNextLine(BufferedReader is) {
        String line;

        try {
            while ((line = is.readLine()) != null) {
                StringTokenizer st = new StringTokenizer(line);
                if (st.hasMoreElements() == false) continue;
                String token = st.nextToken();
                if (token.charAt(0) == '#')continue;
                return line;
            }
        } catch (Exception e) {
            return null;
        }
        return null;
    }

    static String checkLoadModule(String line) {
        int offset = 0;
        int offset2 = 0;
        StringTokenizer st = new StringTokenizer(line);
        String token = st.nextToken();
        String modname;

        if (token.equalsIgnoreCase("LoadModule") == false){
            return null;
        }

        offset = line.lastIndexOf('/');
        if ( offset == -1) {
            return null;
        }

        offset2 = line.lastIndexOf('\"');
        if (( offset2 == -1) || (offset > offset2)) {
            modname = line.substring( offset + 1 );
        }
        else {
            modname = line.substring( offset + 1, offset2 );
        }

        st = new StringTokenizer(modname);
        token = st.nextToken();

        if (token == null) return null;
        if (token.equalsIgnoreCase("mod_log_config.so") == true ) return null;
        if (token.equalsIgnoreCase("mod_ibm_ssl.so") == true ) return null;
        //if (token.equalsIgnoreCase("mod_was_ap20_http.so") == true ) return null;
        if ((token.equalsIgnoreCase("mod_was_ap20_http.so") == true) ||
        	(token.equalsIgnoreCase("mod_was_ap20_http.sl") == true) ||
        	(token.equalsIgnoreCase("mod_was_ap20_http.dll") == true)) return null;
        return new String("ERROR: httpd.conf contains invalid LoadModule directive: " + token);
    }

    static String checkSSLCipherSpec(String line) {
        StringTokenizer st = new StringTokenizer(line);
        String token = st.nextToken();

        if (token.equalsIgnoreCase("SSLCipherSpec") == true){
            return "ERROR: httpd.conf contains SSLCipherSpec directive";
        }
        return null;
    }

    static String checkFIPSEnable(String line) {
        StringTokenizer st = new StringTokenizer(line);
        String token = st.nextToken();

        if (token.equalsIgnoreCase("SSLFIPSEnable") == true){
            if (inVHost == true){
                vhSSLFIPSEnabled = true;
            }
            else {
                SSLFIPSEnabled = true;
            }
        }
        return null;
    }

    static String checkSSLEnable(String line) {
        StringTokenizer st = new StringTokenizer(line);
        String token = st.nextToken();

        if (token.equalsIgnoreCase("SSLEnable") == true){
            if (inVHost == true){
                vhSSLEnabled = true;
            }
            else {
                SSLEnabled = true;
            }
        }
        return null;
    }

    static String checkFIPSDisable(String line) {
        StringTokenizer st = new StringTokenizer(line);
        String token = st.nextToken();

        if (token.equalsIgnoreCase("SSLFIPSDisable") == true){
            return "ERROR: SSLFIPSDisable directive found";
        }
        return null;
    }

    static String checkVHostStart(String line) {
        StringTokenizer st = new StringTokenizer(line);
        String token = st.nextToken();

        if (token.equalsIgnoreCase("<VHost") == true){
            if (inVHost == true){
                return "ERROR: Invalid virtual vost configuration (for unexpected check whitespace)";
            }
            inVHost = true;
            vhSSLFIPSEnabled = false;
            vhSSLEnabled = false;
        }
        return null;
    }

    static String checkVHostEnd(String line) {
        StringTokenizer st = new StringTokenizer(line);
        String token = st.nextToken();

        if (token.equalsIgnoreCase("</VHost>") == true){
            if (inVHost == false){
                return "ERROR: Invalid virtual vost configuration (for unexpected check whitespace)";
            }
            if (validateFIPS() != null){
                return validateFIPS();
            }
            inVHost = false;
        }
        return null;
    }

    static String validateFIPS() {
        if (inVHost == true){
            if (vhSSLEnabled == true){
                if (vhSSLFIPSEnabled == false) {
                    return "ERROR: Missing SSLFIPSEnable directive in VHost";
                }
            }
            else {
                if (vhSSLFIPSEnabled == true) {
                    return "ERROR: Missing SSLEnable directive in VHost";
                }
            }
        }
        else {
            if (SSLEnabled == true){
                if (SSLFIPSEnabled == false) {
                    return "ERROR: Missing SSLFIPSEnable directive";
                }
            }
            else {
                if (SSLFIPSEnabled == true) {
                    return "ERROR: Missing SSLEnable directive";
                }
            }
        }
        return null;
    }

    static String scanConf(String confFile) {
        BufferedReader is = null;
        String line;

        try {
            is = new BufferedReader(new FileReader(confFile));

            while ((line = getNextLine(is)) != null){
                String rsp;

                checkSSLEnable(line);
                checkFIPSEnable(line);

                if ((rsp = checkVHostStart(line)) != null){
                    return rsp;
                }
                if ((rsp = checkVHostEnd(line)) != null){
                    return rsp;
                }
                if ((rsp = checkFIPSDisable(line)) != null){
                    return rsp;
                }
                if ((rsp = checkLoadModule(line)) != null){
                    return rsp;
                }
                if ((rsp = checkSSLCipherSpec(line))!= null){
                    return rsp;
                }
                //Debug System.out.println(line);
            }
            is.close();
            if (inVHost == true) {
                return "ERROR: Invalid virtual vost configuration (for unexpected check whitespace)";
            }
            return validateFIPS();

        } catch (FileNotFoundException e) {
                System.err.println(e);
        } catch (Exception e) {
                System.err.println(e);
        }
        return "ERROR: Unexpected exception encountered";
    }

    public static void main(String[] args) {
        if (args.length > 0 ){
            String rsp = scanConf(args[0]);
            if (rsp == null) {
                System.out.println("SUCCESS: System conforms to required EAL4 configuration");
            }
            else {
                System.out.println("ERROR: System does not conform to required EAL4 configuration");
                System.out.println(rsp);
            }
        }
        else {
            System.out.print("Syntax: java EAL4Verify.class _path_to_config_file_");
        }
    }
}
